@@ -2,7 +2,7 @@
    packageStartupMessage("R/qtlmt is loaded")
 }
 .noGenerics <- TRUE
-.onUnload <- function(libpath){
-   library.dynam.unload("qtlmt", libpath)
-}
+#.onUnload <- function(libpath){
+#   library.dynam.unload("qtlmt", libpath)
+#}
 
